==> openGion6.9.9.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2018/03/29 14:26:31                                            */
/****************************************************************************/

CREATE TABLE GE20 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       VARCHAR (   10 )                    NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        VARCHAR (  500 )                    NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     VARCHAR (   50 )                    NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        VARCHAR ( 4000 )                                        /*  50 設定値   */
 , KBSET        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者   */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE20S.sql <==
/****************************************************************************/
/* GE20 ( ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2018/09/28 16:03:31                                            */
/****************************************************************************/

CREATE TABLE GE20 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , USERID       VARCHAR (   10 )                    NOT NULL            /*  20 ﾕｰｻﾞｰID  */
 , ROLES        VARCHAR ( 2000 )                    NOT NULL            /*  30 ﾛｰﾙｽﾞ    */
 , PARAM_ID     VARCHAR (  200 )                    NOT NULL            /*  40 ﾊﾟﾗﾒｰﾀID */
 , PARAM        VARCHAR ( 4000 )                                        /*  50 設定値   */
 , KBSET        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*  60 設定区分 */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者   */
);
